@@ -8,6 +8,7 @@
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 """Command for `verdi plugins`."""
+import inspect
 
 import click
 
@@ -48,11 +49,11 @@ def plugin_list(entry_point_group, entry_point):
             echo.echo_critical(str(exception))
         else:
             try:
-                if issubclass(plugin, Process):
+                if (inspect.isclass(plugin) and issubclass(plugin, Process)) or plugin.is_process_function:
                     print_process_info(plugin)
                 else:
                     echo.echo(str(plugin.get_description()))
-            except (AttributeError, TypeError):
+            except AttributeError:
                 echo.echo_error('No description available for {}'.format(entry_point))
     else:
         entry_points = get_entry_point_names(entry_point_group)
