@@ -8,7 +8,6 @@
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 """Reusable command line interface options for the setup commands."""
-
 import functools
 import getpass
 import hashlib
@@ -229,6 +228,18 @@ QUICKSETUP_SUPERUSER_DATABASE_PASSWORD = options.OverridableOption(
     default=DEFAULT_DBINFO['password'],
 )
 
+QUICKSETUP_BROKER_PROTOCOL = options.BROKER_PROTOCOL
+
+QUICKSETUP_BROKER_USERNAME = options.BROKER_USERNAME
+
+QUICKSETUP_BROKER_PASSWORD = options.BROKER_PASSWORD
+
+QUICKSETUP_BROKER_HOST = options.BROKER_HOST
+
+QUICKSETUP_BROKER_PORT = options.BROKER_PORT
+
+QUICKSETUP_BROKER_VIRTUAL_HOST = options.BROKER_VIRTUAL_HOST
+
 QUICKSETUP_REPOSITORY_URI = options.REPOSITORY_PATH.clone(
     callback=get_quicksetup_repository_uri  # Cannot use `default` because `ctx` is needed to determine the default
 )
@@ -278,6 +289,48 @@ SETUP_DATABASE_PASSWORD = QUICKSETUP_DATABASE_PASSWORD.clone(
     cls=options.interactive.InteractiveOption
 )
 
+SETUP_BROKER_PROTOCOL = QUICKSETUP_BROKER_PROTOCOL.clone(
+    prompt='Broker protocol',
+    required=True,
+    contextual_default=functools.partial(get_profile_attribute_default, ('broker_protocol', None)),
+    cls=options.interactive.InteractiveOption
+)
+
+SETUP_BROKER_USERNAME = QUICKSETUP_BROKER_USERNAME.clone(
+    prompt='Broker username',
+    required=True,
+    contextual_default=functools.partial(get_profile_attribute_default, ('broker_username', None)),
+    cls=options.interactive.InteractiveOption
+)
+
+SETUP_BROKER_PASSWORD = QUICKSETUP_BROKER_PASSWORD.clone(
+    prompt='Broker password',
+    required=True,
+    contextual_default=functools.partial(get_profile_attribute_default, ('broker_password', None)),
+    cls=options.interactive.InteractiveOption
+)
+
+SETUP_BROKER_HOST = QUICKSETUP_BROKER_HOST.clone(
+    prompt='Broker host',
+    required=True,
+    contextual_default=functools.partial(get_profile_attribute_default, ('broker_host', None)),
+    cls=options.interactive.InteractiveOption
+)
+
+SETUP_BROKER_PORT = QUICKSETUP_BROKER_PORT.clone(
+    prompt='Broker port',
+    required=True,
+    contextual_default=functools.partial(get_profile_attribute_default, ('broker_port', None)),
+    cls=options.interactive.InteractiveOption
+)
+
+SETUP_BROKER_VIRTUAL_HOST = QUICKSETUP_BROKER_VIRTUAL_HOST.clone(
+    prompt='Broker virtual host name',
+    required=True,
+    contextual_default=functools.partial(get_profile_attribute_default, ('broker_virtual_host', None)),
+    cls=options.interactive.InteractiveOption
+)
+
 SETUP_REPOSITORY_URI = QUICKSETUP_REPOSITORY_URI.clone(
     prompt='Repository directory',
     callback=None,  # Unset the `callback` to define the default, which is instead done by the `contextual_default`
