@@ -14,9 +14,9 @@ the routines make reference to the suitable plugins for all
 plugin-specific operations.
 """
 import os
+import shutil
 
 from aiida.common import AIIDA_LOGGER, exceptions
-from aiida.common.datastructures import CalcJobState
 from aiida.common.folders import SandboxFolder
 from aiida.common.links import LinkType
 from aiida.orm import FolderData, Node
@@ -37,6 +37,7 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
     :param calc_info: the calculation info datastructure returned by `CalcJob.presubmit`
     :param folder: temporary local file system folder containing the inputs written by `CalcJob.prepare_for_submission`
     """
+    # pylint: disable=too-many-locals,too-many-branches,too-many-statements
     from logging import LoggerAdapter
     from tempfile import NamedTemporaryFile
     from aiida.orm import load_node, Code, RemoteData
@@ -59,21 +60,23 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
     logger = LoggerAdapter(logger=execlogger, extra=logger_extra)
 
     if not dry_run and node.has_cached_links():
-        raise ValueError('Cannot submit calculation {} because it has cached input links! If you just want to test the '
-                         'submission, set `metadata.dry_run` to True in the inputs.'.format(node.pk))
+        raise ValueError(
+            'Cannot submit calculation {} because it has cached input links! If you just want to test the '
+            'submission, set `metadata.dry_run` to True in the inputs.'.format(node.pk)
+        )
 
     # If we are performing a dry-run, the working directory should actually be a local folder that should already exist
     if dry_run:
         workdir = transport.getcwd()
     else:
         remote_user = transport.whoami()
-        # TODO Doc: {username} field
-        # TODO: if something is changed here, fix also 'verdi computer test'
         remote_working_directory = computer.get_workdir().format(username=remote_user)
         if not remote_working_directory.strip():
             raise exceptions.ConfigurationError(
                 "[submission of calculation {}] No remote_working_directory configured for computer '{}'".format(
-                    node.pk, computer.name))
+                    node.pk, computer.label
+                )
+            )
 
         # If it already exists, no exception is raised
         try:
@@ -81,7 +84,9 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
         except IOError:
             logger.debug(
                 '[submission of calculation {}] Unable to chdir in {}, trying to create it'.format(
-                    node.pk, remote_working_directory))
+                    node.pk, remote_working_directory
+                )
+            )
             try:
                 transport.makedirs(remote_working_directory)
                 transport.chdir(remote_working_directory)
@@ -89,8 +94,8 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
                 raise exceptions.ConfigurationError(
                     '[submission of calculation {}] '
                     'Unable to create the remote directory {} on '
-                    "computer '{}': {}".format(
-                        node.pk, remote_working_directory, computer.name, exc))
+                    "computer '{}': {}".format(node.pk, remote_working_directory, computer.label, exc)
+                )
         # Store remotely with sharding (here is where we choose
         # the folder structure of remote jobs; then I store this
         # in the calculation properties using _set_remote_dir
@@ -112,8 +117,11 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
             path_existing = os.path.join(transport.getcwd(), calc_info.uuid[4:])
             path_lost_found = os.path.join(remote_working_directory, REMOTE_WORK_DIRECTORY_LOST_FOUND)
             path_target = os.path.join(path_lost_found, calc_info.uuid)
-            logger.warning('tried to create path {} but it already exists, moving the entire folder to {}'.format(
-                path_existing, path_target))
+            logger.warning(
+                'tried to create path {} but it already exists, moving the entire folder to {}'.format(
+                    path_existing, path_target
+                )
+            )
 
             # Make sure the lost+found directory exists, then copy the existing folder there and delete the original
             transport.mkdir(path_lost_found, ignore_existing=True)
@@ -136,27 +144,22 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
     for code in input_codes:
         if code.is_local():
             # Note: this will possibly overwrite files
-            for f in code.list_object_names():
+            for filename in code.list_object_names():
                 # Note, once #2579 is implemented, use the `node.open` method instead of the named temporary file in
                 # combination with the new `Transport.put_object_from_filelike`
                 # Since the content of the node could potentially be binary, we read the raw bytes and pass them on
                 with NamedTemporaryFile(mode='wb+') as handle:
-                    handle.write(code.get_object_content(f, mode='rb'))
+                    handle.write(code.get_object_content(filename, mode='rb'))
                     handle.flush()
-                    transport.put(handle.name, f)
+                    transport.put(handle.name, filename)
             transport.chmod(code.get_local_executable(), 0o755)  # rwxr-xr-x
 
-    # In a dry_run, the working directory is the raw input folder, which will already contain these resources
-    if not dry_run:
-        for filename in folder.get_content_list():
-            logger.debug('[submission of calculation {}] copying file/folder {}...'.format(node.pk, filename))
-            transport.put(folder.get_abs_path(filename), filename)
-
     # local_copy_list is a list of tuples, each with (uuid, dest_rel_path)
     # NOTE: validation of these lists are done inside calculation.presubmit()
     local_copy_list = calc_info.local_copy_list or []
     remote_copy_list = calc_info.remote_copy_list or []
     remote_symlink_list = calc_info.remote_symlink_list or []
+    provenance_exclude_list = calc_info.provenance_exclude_list or []
 
     for uuid, filename, target in local_copy_list:
         logger.debug('[submission of calculation {}] copying local file/folder to {}'.format(node.uuid, target))
@@ -168,10 +171,10 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
             :param uuid: UUID of the node to find
             :return: instance of `Node` or `None` if not found
             """
-            from collections import Mapping
+            from collections.abc import Mapping
             data_node = None
 
-            for link_label, input_node in inputs.items():
+            for input_node in inputs.values():
                 if isinstance(input_node, Mapping):
                     data_node = find_data_node(input_node, uuid)
                 elif isinstance(input_node, Node) and input_node.uuid == uuid:
@@ -189,59 +192,80 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
         if data_node is None:
             logger.warning('failed to load Node<{}> specified in the `local_copy_list`'.format(uuid))
         else:
-            # Note, once #2579 is implemented, use the `node.open` method instead of the named temporary file in
-            # combination with the new `Transport.put_object_from_filelike`
-            # Since the content of the node could potentially be binary, we read the raw bytes and pass them on
-            with NamedTemporaryFile(mode='wb+') as handle:
-                handle.write(data_node.get_object_content(filename, mode='rb'))
-                handle.flush()
-                transport.put(handle.name, target)
+            dirname = os.path.dirname(target)
+            if dirname:
+                os.makedirs(os.path.join(folder.abspath, dirname), exist_ok=True)
+            with folder.open(target, 'wb') as handle:
+                with data_node.open(filename, 'rb') as source:
+                    shutil.copyfileobj(source, handle)
+            provenance_exclude_list.append(target)
 
-    if dry_run:
-        if remote_copy_list:
-            with open(os.path.join(workdir, '_aiida_remote_copy_list.txt'), 'w') as handle:
-                for remote_computer_uuid, remote_abs_path, dest_rel_path in remote_copy_list:
-                    handle.write('would have copied {} to {} in working directory on remote {}'.format(
-                        remote_abs_path, dest_rel_path, computer.name))
-
-        if remote_symlink_list:
-            with open(os.path.join(workdir, '_aiida_remote_symlink_list.txt'), 'w') as handle:
-                for remote_computer_uuid, remote_abs_path, dest_rel_path in remote_symlink_list:
-                    handle.write('would have created symlinks from {} to {} in working directory on remote {}'.format(
-                        remote_abs_path, dest_rel_path, computer.name))
-
-    else:
+    # In a dry_run, the working directory is the raw input folder, which will already contain these resources
+    if not dry_run:
+        for filename in folder.get_content_list():
+            logger.debug('[submission of calculation {}] copying file/folder {}...'.format(node.pk, filename))
+            transport.put(folder.get_abs_path(filename), filename)
 
         for (remote_computer_uuid, remote_abs_path, dest_rel_path) in remote_copy_list:
             if remote_computer_uuid == computer.uuid:
-                logger.debug('[submission of calculation {}] copying {} remotely, directly on the machine {}'.format(
-                    node.pk, dest_rel_path, computer.name))
+                logger.debug(
+                    '[submission of calculation {}] copying {} remotely, directly on the machine {}'.format(
+                        node.pk, dest_rel_path, computer.label
+                    )
+                )
                 try:
                     transport.copy(remote_abs_path, dest_rel_path)
                 except (IOError, OSError):
-                    logger.warning('[submission of calculation {}] Unable to copy remote resource from {} to {}! '
-                                   'Stopping.'.format(node.pk, remote_abs_path, dest_rel_path))
+                    logger.warning(
+                        '[submission of calculation {}] Unable to copy remote resource from {} to {}! '
+                        'Stopping.'.format(node.pk, remote_abs_path, dest_rel_path)
+                    )
                     raise
             else:
                 raise NotImplementedError(
                     '[submission of calculation {}] Remote copy between two different machines is '
-                    'not implemented yet'.format(node.pk))
+                    'not implemented yet'.format(node.pk)
+                )
 
         for (remote_computer_uuid, remote_abs_path, dest_rel_path) in remote_symlink_list:
             if remote_computer_uuid == computer.uuid:
-                logger.debug('[submission of calculation {}] copying {} remotely, directly on the machine {}'.format(
-                    node.pk, dest_rel_path, computer.name))
+                logger.debug(
+                    '[submission of calculation {}] copying {} remotely, directly on the machine {}'.format(
+                        node.pk, dest_rel_path, computer.label
+                    )
+                )
                 try:
                     transport.symlink(remote_abs_path, dest_rel_path)
                 except (IOError, OSError):
-                    logger.warning('[submission of calculation {}] Unable to create remote symlink from {} to {}! '
-                                   'Stopping.'.format(node.pk, remote_abs_path, dest_rel_path))
+                    logger.warning(
+                        '[submission of calculation {}] Unable to create remote symlink from {} to {}! '
+                        'Stopping.'.format(node.pk, remote_abs_path, dest_rel_path)
+                    )
                     raise
             else:
-                raise IOError('It is not possible to create a symlink between two different machines for '
-                              'calculation {}'.format(node.pk))
+                raise IOError(
+                    'It is not possible to create a symlink between two different machines for '
+                    'calculation {}'.format(node.pk)
+                )
+    else:
 
-    provenance_exclude_list = calc_info.provenance_exclude_list or []
+        if remote_copy_list:
+            with open(os.path.join(workdir, '_aiida_remote_copy_list.txt'), 'w') as handle:
+                for remote_computer_uuid, remote_abs_path, dest_rel_path in remote_copy_list:
+                    handle.write(
+                        'would have copied {} to {} in working directory on remote {}'.format(
+                            remote_abs_path, dest_rel_path, computer.label
+                        )
+                    )
+
+        if remote_symlink_list:
+            with open(os.path.join(workdir, '_aiida_remote_symlink_list.txt'), 'w') as handle:
+                for remote_computer_uuid, remote_abs_path, dest_rel_path in remote_symlink_list:
+                    handle.write(
+                        'would have created symlinks from {} to {} in working directory on remote {}'.format(
+                            remote_abs_path, dest_rel_path, computer.label
+                        )
+                    )
 
     # Loop recursively over content of the sandbox folder copying all that are not in `provenance_exclude_list`. Note
     # that directories are not created explicitly. The `node.put_object_from_filelike` call will create intermediate
@@ -250,13 +274,13 @@ def upload_calculation(node, transport, calc_info, folder, inputs=None, dry_run=
     # advantage of this explicit copying instead of deleting the files from `provenance_exclude_list` from the sandbox
     # first before moving the entire remaining content to the node's repository, is that in this way we are guaranteed
     # not to accidentally move files to the repository that should not go there at all cost.
-    for root, dirnames, filenames in os.walk(folder.abspath):
+    for root, _, filenames in os.walk(folder.abspath):
         for filename in filenames:
             filepath = os.path.join(root, filename)
             relpath = os.path.relpath(filepath, folder.abspath)
             if relpath not in provenance_exclude_list:
                 with open(filepath, 'rb') as handle:
-                    node.put_object_from_filelike(handle, relpath, 'wb', force=True)
+                    node._repository.put_object_from_filelike(handle, relpath, 'wb', force=True)  # pylint: disable=protected-access
 
     if not dry_run:
         # Make sure that attaching the `remote_folder` with a link is the last thing we do. This gives the biggest
@@ -319,8 +343,9 @@ def retrieve_calculation(calculation, transport, retrieved_temporary_folder):
     # chance to perform the state transition. Upon reloading this calculation, it will re-attempt the retrieval.
     link_label = calculation.link_label_retrieved
     if calculation.get_outgoing(FolderData, link_label_filter=link_label).first():
-        execlogger.warning('CalcJobNode<{}> already has a `{}` output folder: skipping retrieval'.format(
-            calculation.pk, link_label))
+        execlogger.warning(
+            'CalcJobNode<{}> already has a `{}` output folder: skipping retrieval'.format(calculation.pk, link_label)
+        )
         return
 
     # Create the FolderData node into which to store the files that are to be retrieved
@@ -351,14 +376,17 @@ def retrieve_calculation(calculation, transport, retrieved_temporary_folder):
 
             # Log the files that were retrieved in the temporary folder
             for filename in os.listdir(retrieved_temporary_folder):
-                execlogger.debug("[retrieval of calc {}] Retrieved temporary file or folder '{}'".format(
-                    calculation.pk, filename), extra=logger_extra)
+                execlogger.debug(
+                    "[retrieval of calc {}] Retrieved temporary file or folder '{}'".format(calculation.pk, filename),
+                    extra=logger_extra
+                )
 
         # Store everything
         execlogger.debug(
             '[retrieval of calc {}] '
             'Storing retrieved_files={}'.format(calculation.pk, retrieved_files.pk),
-            extra=logger_extra)
+            extra=logger_extra
+        )
         retrieved_files.store()
 
     # Make sure that attaching the `retrieved` folder with a link is the last thing we do. This gives the biggest chance
@@ -398,72 +426,15 @@ def kill_calculation(calculation, transport):
     return True
 
 
-def parse_results(process, retrieved_temporary_folder=None):
-    """
-    Parse the results for a given CalcJobNode (job)
-
-    :returns: integer exit code, where 0 indicates success and non-zero failure
-    """
-    from aiida.engine import ExitCode
-
-    assert process.node.get_state() == CalcJobState.PARSING, \
-        'job should be in the PARSING state when calling this function yet it is {}'.format(process.node.get_state())
-
-    parser_class = process.node.get_parser_class()
-    exit_code = ExitCode()
-    logger_extra = get_dblogger_extra(process.node)
-
-    if retrieved_temporary_folder:
-        files = []
-        for root, directories, filenames in os.walk(retrieved_temporary_folder):
-            for directory in directories:
-                files.append('- [D] {}'.format(os.path.join(root, directory)))
-            for filename in filenames:
-                files.append('- [F] {}'.format(os.path.join(root, filename)))
-
-        execlogger.debug('[parsing of calc {}] '
-                         'Content of the retrieved_temporary_folder: \n'
-                         '{}'.format(process.node.pk, '\n'.join(files)), extra=logger_extra)
-    else:
-        execlogger.debug('[parsing of calc {}] '
-                         'No retrieved_temporary_folder.'.format(process.node.pk), extra=logger_extra)
-
-    if parser_class is not None:
-
-        parser = parser_class(process.node)
-        parse_kwargs = parser.get_outputs_for_parsing()
-
-        if retrieved_temporary_folder:
-            parse_kwargs['retrieved_temporary_folder'] = retrieved_temporary_folder
-
-        exit_code = parser.parse(**parse_kwargs)
-
-        if exit_code is None:
-            exit_code = ExitCode(0)
-
-        if not isinstance(exit_code, ExitCode):
-            raise ValueError('parse should return an `ExitCode` or None, and not {}'.format(type(exit_code)))
-
-        if exit_code.status:
-            parser.logger.error('parser returned exit code<{}>: {}'.format(exit_code.status, exit_code.message))
-
-        for link_label, node in parser.outputs.items():
-            try:
-                process.out(link_label, node)
-            except ValueError as exception:
-                parser.logger.error('invalid value {} specified with label {}: {}'.format(node, link_label, exception))
-                exit_code = process.exit_codes.ERROR_INVALID_OUTPUT
-                break
-
-    return exit_code
-
-
 def _retrieve_singlefiles(job, transport, folder, retrieve_file_list, logger_extra=None):
+    """Retrieve files specified through the singlefile list mechanism."""
     singlefile_list = []
     for (linkname, subclassname, filename) in retrieve_file_list:
-        execlogger.debug('[retrieval of calc {}] Trying '
-                         "to retrieve remote singlefile '{}'".format(
-            job.pk, filename), extra=logger_extra)
+        execlogger.debug(
+            '[retrieval of calc {}] Trying '
+            "to retrieve remote singlefile '{}'".format(job.pk, filename),
+            extra=logger_extra
+        )
         localfilename = os.path.join(folder.abspath, os.path.split(filename)[1])
         transport.get(filename, localfilename, ignore_nonexisting=True)
         singlefile_list.append((linkname, subclassname, localfilename))
@@ -474,16 +445,16 @@ def _retrieve_singlefiles(job, transport, folder, retrieve_file_list, logger_ext
     # after retrieving from the cluster, I create the objects
     singlefiles = []
     for (linkname, subclassname, filename) in singlefile_list:
-        SinglefileSubclass = DataFactory(subclassname)
-        singlefile = SinglefileSubclass(file=filename)
+        cls = DataFactory(subclassname)
+        singlefile = cls(file=filename)
         singlefile.add_incoming(job, link_type=LinkType.CREATE, link_label=linkname)
         singlefiles.append(singlefile)
 
     for fil in singlefiles:
         execlogger.debug(
             '[retrieval of calc {}] '
-            'Storing retrieved_singlefile={}'.format(job.pk, fil.pk),
-            extra=logger_extra)
+            'Storing retrieved_singlefile={}'.format(job.pk, fil.pk), extra=logger_extra
+        )
         fil.store()
 
 
@@ -507,12 +478,12 @@ def retrieve_files_from_list(calculation, transport, folder, retrieve_list):
     treated as the work directory of the folder and the depth integer determines
     upto what level of the original remotepath nesting the files will be copied.
 
-    :param transport: the Transport instance
-    :param folder: an absolute path to a folder to copy files in
-    :param retrieve_list: the list of files to retrieve
+    :param transport: the Transport instance.
+    :param folder: an absolute path to a folder that contains the files to copy.
+    :param retrieve_list: the list of files to retrieve.
     """
     for item in retrieve_list:
-        if isinstance(item, list):
+        if isinstance(item, (list, tuple)):
             tmp_rname, tmp_lname, depth = item
             # if there are more than one file I do something differently
             if transport.has_magic(tmp_rname):
@@ -523,13 +494,11 @@ def retrieve_files_from_list(calculation, transport, folder, retrieve_list):
                     local_names.append(os.path.sep.join([tmp_lname] + to_append))
             else:
                 remote_names = [tmp_rname]
-                to_append = remote_names.split(os.path.sep)[-depth:] if depth > 0 else []
+                to_append = tmp_rname.split(os.path.sep)[-depth:] if depth > 0 else []
                 local_names = [os.path.sep.join([tmp_lname] + to_append)]
             if depth > 1:  # create directories in the folder, if needed
                 for this_local_file in local_names:
-                    new_folder = os.path.join(
-                        folder,
-                        os.path.split(this_local_file)[0])
+                    new_folder = os.path.join(folder, os.path.split(this_local_file)[0])
                     if not os.path.exists(new_folder):
                         os.makedirs(new_folder)
         else:  # it is a string
@@ -542,5 +511,6 @@ def retrieve_files_from_list(calculation, transport, folder, retrieve_list):
 
         for rem, loc in zip(remote_names, local_names):
             transport.logger.debug(
-                "[retrieval of calc {}] Trying to retrieve remote item '{}'".format(calculation.pk, rem))
+                "[retrieval of calc {}] Trying to retrieve remote item '{}'".format(calculation.pk, rem)
+            )
             transport.get(rem, os.path.join(folder, loc), ignore_nonexisting=True)
