@@ -7,29 +7,23 @@
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
+# pylint: disable=no-self-use
+""""Implementation of `DbImporter` for the CISD database."""
+import io
 
-
-
-from aiida.tools.dbimporters.baseclasses import (DbImporter, DbSearchResults,
-                                                 CifEntry)
+from aiida.tools.dbimporters.baseclasses import DbImporter, DbSearchResults, CifEntry
 
 
 class IcsdImporterExp(Exception):
-    pass
+    """Base class for ICSD exceptions."""
 
 
 class CifFileErrorExp(IcsdImporterExp):
-    """
-    Raised when the author loop is missing in a CIF file.
-    """
-    pass
+    """Raised when the author loop is missing in a CIF file."""
 
 
 class NoResultsWebExp(IcsdImporterExp):
-    """
-    Raised when a webpage query returns no results.
-    """
-    pass
+    """Raised when a webpage query returns no results."""
 
 
 class IcsdDbImporter(DbImporter):
@@ -82,15 +76,16 @@ class IcsdDbImporter(DbImporter):
 
     def __init__(self, **kwargs):
 
-        self.db_parameters = {'server': '',
-                              'urladd': 'index.php?',
-                              'querydb': True,
-                              'dl_db': 'icsd',
-                              'host': '',
-                              'user': 'dba',
-                              'passwd': 'sql',
-                              'db': 'icsd',
-                              'port': '3306',
+        self.db_parameters = {
+            'server': '',
+            'urladd': 'index.php?',
+            'querydb': True,
+            'dl_db': 'icsd',
+            'host': '',
+            'user': 'dba',
+            'passwd': 'sql',
+            'db': 'icsd',
+            'port': '3306',
         }
         self.setup_db(**kwargs)
 
@@ -103,69 +98,61 @@ class IcsdDbImporter(DbImporter):
         :param values: Corresponding values from query
         :return: SQL query predicate
         """
-        for e in values:
-            if not isinstance(e, int) and not isinstance(e, str):
-                raise ValueError("incorrect value for keyword '" + alias + \
-                                 "' -- only integers and strings are accepted")
+        for value in values:
+            if not isinstance(value, int) and not isinstance(value, str):
+                raise ValueError("incorrect value for keyword '" + alias + ' only integers and strings are accepted')
         return '{} IN ({})'.format(key, ', '.join(str(int(i)) for i in values))
 
     def _str_exact_clause(self, key, alias, values):
         """
         Return SQL query predicate for querying string fields.
         """
-        for e in values:
-            if not isinstance(e, int) and not isinstance(e, str):
-                raise ValueError("incorrect value for keyword '" + alias + \
-                                 "' -- only integers and strings are accepted")
+        for value in values:
+            if not isinstance(value, int) and not isinstance(value, str):
+                raise ValueError("incorrect value for keyword '" + alias + ' only integers and strings are accepted')
         return '{} IN ({})'.format(key, ', '.join("'{}'".format(f) for f in values))
 
     def _formula_clause(self, key, alias, values):
         """
         Return SQL query predicate for querying formula fields.
         """
-        for e in values:
-            if not isinstance(e, str):
-                raise ValueError("incorrect value for keyword '" + alias + \
-                                 "' -- only strings are accepted")
-        return self._str_exact_clause(key, \
-                                     alias, \
-                                     [str(f) for f in values])
+        for value in values:
+            if not isinstance(value, str):
+                raise ValueError("incorrect value for keyword '" + alias + ' only strings are accepted')
+        return self._str_exact_clause(key, alias, [str(f) for f in values])
 
     def _str_fuzzy_clause(self, key, alias, values):
         """
         Return SQL query predicate for fuzzy querying of string fields.
         """
-        for e in values:
-            if not isinstance(e, int) and not isinstance(e, str):
-                raise ValueError("incorrect value for keyword '" + alias + \
-                                 "' -- only integers and strings are accepted")
+        for value in values:
+            if not isinstance(value, int) and not isinstance(value, str):
+                raise ValueError("incorrect value for keyword '" + alias + ' only integers and strings are accepted')
         return ' OR '.join("{} LIKE '%{}%'".format(key, s) for s in values)
 
-    def _composition_clause(self, key, alias, values):
+    def _composition_clause(self, key, alias, values):  # pylint: disable=unused-argument
         """
         Return SQL query predicate for querying elements in formula fields.
         """
-        for e in values:
-            if not isinstance(e, str):
-                raise ValueError("incorrect value for keyword '" + alias + \
-                                 "' -- only strings are accepted")
+        for value in values:
+            if not isinstance(value, str):
+                raise ValueError("incorrect value for keyword '" + alias + ' only strings are accepted')
         # SUM_FORM in the ICSD always stores a numeral after the element name,
         # STRUCT_FORM does not, so it's better to use SUM_FORM for the composition query.
         # The element-numeral pair can be in the beginning of the formula expression (therefore no space before),
         # or at the end of the formula expression (no space after).
         # Be aware that one needs to check that space/beginning of line before and ideally also space/end of line
         # after, because I found that capitalization of the element name is not enforced in these queries.
-        return ' AND '.join(r'SUM_FORM REGEXP \'(^|\ ){}[0-9\.]+($|\ )\''.format(e) for e in values)
+        return ' AND '.join(r'SUM_FORM REGEXP \'(^|\ ){}[0-9\.]+($|\ )\''.format(value) for value in values)
 
     def _double_clause(self, key, alias, values, precision):
         """
         Return SQL query predicate for querying double-valued fields.
         """
-        for e in values:
-            if not isinstance(e, int) and not isinstance(e, float):
-                raise ValueError("incorrect value for keyword '" + alias + \
-                                 "' -- only integers and floats are accepted")
-        return ' OR '.join('{} BETWEEN {} AND {}'.format(key, d-precision, d+precision) for d in values)
+        for value in values:
+            if not isinstance(value, int) and not isinstance(value, float):
+                raise ValueError("incorrect value for keyword '" + alias + ' only integers and floats are accepted')
+        return ' OR '.join('{} BETWEEN {} AND {}'.format(key, d - precision, d + precision) for d in values)
 
     def _crystal_system_clause(self, key, alias, values):
         """
@@ -181,117 +168,127 @@ class IcsdDbImporter(DbImporter):
             'triclinic': 'TC'
         }  # from icsd accepted crystal systems
 
-        for e in values:
-            if not isinstance(e, int) and not isinstance(e, str):
-                raise ValueError("incorrect value for keyword '" + alias + \
-                                 "' -- only strings are accepted")
+        for value in values:
+            if not isinstance(value, int) and not isinstance(value, str):
+                raise ValueError("incorrect value for keyword '" + alias + ' only strings are accepted')
         return key + ' IN (' + ', '.join("'" + valid_systems[f.lower()] + "'" for f in values) + ')'
 
     def _length_clause(self, key, alias, values):
         """
         Return SQL query predicate for querying lattice vector lengths.
         """
-        return self.double_clause(key, alias, values, self.length_precision)
+        return self._double_clause(key, alias, values, self.length_precision)
 
     def _density_clause(self, key, alias, values):
         """
         Return SQL query predicate for querying density.
         """
-        return self.double_clause(key, alias, values, self.density_precision)
+        return self._double_clause(key, alias, values, self.density_precision)
 
     def _angle_clause(self, key, alias, values):
         """
         Return SQL query predicate for querying lattice angles.
         """
-        return self.double_clause(key, alias, values, self.angle_precision)
+        return self._double_clause(key, alias, values, self.angle_precision)
 
     def _volume_clause(self, key, alias, values):
         """
         Return SQL query predicate for querying unit cell volume.
         """
-        return self.double_clause(key, alias, values, self.volume_precision)
+        return self._double_clause(key, alias, values, self.volume_precision)
 
     def _temperature_clause(self, key, alias, values):
         """
         Return SQL query predicate for querying temperature.
         """
-        return self.double_clause(key, alias, values, self.temperature_precision)
+        return self._double_clause(key, alias, values, self.temperature_precision)
 
     def _pressure_clause(self, key, alias, values):
         """
         Return SQL query predicate for querying pressure.
         """
-        return self.double_clause(key, alias, values, self.pressure_precision)
+        return self._double_clause(key, alias, values, self.pressure_precision)
 
     # for the web query
-    def _parse_all(k, v):
+    @staticmethod
+    def _parse_all(key, values):  # pylint: disable=unused-argument
         """
         Convert numbers, strings, lists into strings.
-        :param k: query parameter
-        :param v: corresponding values
+        :param key: query parameter
+        :param values: corresponding values
         :return retval: string
         """
-        if type(v) is list:
-            retval = ' '.join(v)
-        elif type(v) is int:
-            retval = str(v)
-        elif type(v) is str:
-            retval = v
+        if isinstance(values, list):
+            retval = ' '.join(values)
+        elif isinstance(values, int):
+            retval = str(values)
+        elif isinstance(values, str):
+            retval = values
         return retval
 
-    def _parse_number(k, v):
+    @staticmethod
+    def _parse_number(key, values):  # pylint: disable=unused-argument
         """
         Convert int into string.
-        :param k: query parameter
-        :param v: corresponding values
+        :param key: query parameter
+        :param values: corresponding values
         :return retval: string
         """
-        if type(v) is int:
-            retval = str(v)
-        elif type(v) is str:
-            retval = v
+        if isinstance(values, int):
+            retval = str(values)
+        elif isinstance(values, str):
+            retval = values
         return retval
 
-    def _parse_mineral(k, v):
+    @staticmethod
+    def _parse_mineral(key, values):
         """
         Convert mineral_name and chemical_name into right format.
-        :param k: query parameter
-        :param v: corresponding values
+        :param key: query parameter
+        :param values: corresponding values
         :return retval: string
         """
-        if k == 'mineral_name':
-            retval = 'M=' + v
-        elif k == 'chemical_name':
-            retval = 'C=' + v
+        if key == 'mineral_name':
+            retval = 'M=' + values
+        elif key == 'chemical_name':
+            retval = 'C=' + values
         return retval
 
-    def _parse_volume(k, v):
+    @staticmethod
+    def _parse_volume(key, values):  # pylint: disable=too-many-return-statements
         """
         Convert volume, cell parameter and angle queries into right format.
-        :param k: query parameter
-        :param v: corresponding values
+        :param key: query parameter
+        :param values: corresponding values
         :return retval: string
         """
-        if k == 'volume':
-            return 'v=' + v
-        elif k == 'a':
-            return 'a=' + v
-        elif k == 'b':
-            return 'b=' + v
-        elif k == 'c':
-            return 'c=' + v
-        elif k == 'alpha':
-            return 'al=' + v
-        elif k == 'beta':
-            return 'be=' + v
-        elif k == 'gamma':
-            return 'ga=' + v
+        if key == 'volume':
+            return 'v=' + values
 
-    def _parse_system(k, v):
+        if key == 'a':
+            return 'a=' + values
+
+        if key == 'b':
+            return 'b=' + values
+
+        if key == 'c':
+            return 'c=' + values
+
+        if key == 'alpha':
+            return 'al=' + values
+
+        if key == 'beta':
+            return 'be=' + values
+
+        if key == 'gamma':
+            return 'ga=' + values
+
+    @staticmethod
+    def _parse_system(key, values):  # pylint: disable=unused-argument
         """
         Return crystal system in the right format.
-        :param k: query parameter
-        :param v: corresponding values
+        :param key: query parameter
+        :param values: corresponding values
         :return retval: string
         """
         valid_systems = {
@@ -304,54 +301,56 @@ class IcsdDbImporter(DbImporter):
             'triclinic': 'TC'
         }
 
-        return valid_systems[v.lower()]
+        return valid_systems[values.lower()]
 
     # mysql database - query parameter (alias) : [mysql keyword (key), function to call]
-    keywords_db = {'id': ['COLL_CODE', _int_clause],
-                   'element': ['SUM_FORM;', _composition_clause],
-                   'number_of_elements': ['EL_COUNT', _int_clause],
-                   'chemical_name': ['CHEM_NAME', _str_fuzzy_clause],
-                   'formula': ['SUM_FORM', _formula_clause],
-                   'volume': ['C_VOL', _volume_clause],
-                   'spacegroup': ['SGR', _str_exact_clause],
-                   'a': ['A_LEN', _length_clause],
-                   'b': ['B_LEN', _length_clause],
-                   'c': ['C_LEN', _length_clause],
-                   'alpha': ['ALPHA', _angle_clause],
-                   'beta': ['BETA', _angle_clause],
-                   'gamma': ['GAMMA', _angle_clause],
-                   'density': ['DENSITY_CALC', _density_clause],
-                   'wyckoff': ['WYCK', _str_exact_clause],
-                   'molar_mass': ['MOL_MASS', _density_clause],
-                   'pdf_num': ['PDF_NUM', _str_exact_clause],
-                   'z': ['Z', _int_clause],
-                   'measurement_temp': ['TEMPERATURE', _temperature_clause],
-                   'authors': ['AUTHORS_TEXT', _str_fuzzy_clause],
-                   'journal': ['journal', _str_fuzzy_clause],
-                   'title': ['AU_TITLE', _str_fuzzy_clause],
-                   'year': ['MPY', _int_clause],
-                   'crystal_system': ['CRYST_SYS_CODE', _crystal_system_clause],
+    keywords_db = {
+        'id': ['COLL_CODE', _int_clause],
+        'element': ['SUM_FORM;', _composition_clause],
+        'number_of_elements': ['EL_COUNT', _int_clause],
+        'chemical_name': ['CHEM_NAME', _str_fuzzy_clause],
+        'formula': ['SUM_FORM', _formula_clause],
+        'volume': ['C_VOL', _volume_clause],
+        'spacegroup': ['SGR', _str_exact_clause],
+        'a': ['A_LEN', _length_clause],
+        'b': ['B_LEN', _length_clause],
+        'c': ['C_LEN', _length_clause],
+        'alpha': ['ALPHA', _angle_clause],
+        'beta': ['BETA', _angle_clause],
+        'gamma': ['GAMMA', _angle_clause],
+        'density': ['DENSITY_CALC', _density_clause],
+        'wyckoff': ['WYCK', _str_exact_clause],
+        'molar_mass': ['MOL_MASS', _density_clause],
+        'pdf_num': ['PDF_NUM', _str_exact_clause],
+        'z': ['Z', _int_clause],
+        'measurement_temp': ['TEMPERATURE', _temperature_clause],
+        'authors': ['AUTHORS_TEXT', _str_fuzzy_clause],
+        'journal': ['journal', _str_fuzzy_clause],
+        'title': ['AU_TITLE', _str_fuzzy_clause],
+        'year': ['MPY', _int_clause],
+        'crystal_system': ['CRYST_SYS_CODE', _crystal_system_clause],
     }
     # keywords accepted for the web page query
-    keywords = {'id': ('authors', _parse_all),
-                'authors': ('authors', _parse_all),
-                'element': ('elements', _parse_all),
-                'number_of_elements': ('elementc', _parse_all),
-                'mineral_name': ('mineral', _parse_mineral),
-                'chemical_name': ('mineral', _parse_mineral),
-                'formula': ('formula', _parse_all),
-                'volume': ('volume', _parse_volume),
-                'a': ('volume', _parse_volume),
-                'b': ('volume', _parse_volume),
-                'c': ('volume', _parse_volume),
-                'alpha': ('volume', _parse_volume),
-                'beta': ('volume', _parse_volume),
-                'gamma': ('volume', _parse_volume),
-                'spacegroup': ('spaceg', _parse_all),
-                'journal': ('journal', _parse_all),
-                'title': ('title', _parse_all),
-                'year': ('year', _parse_all),
-                'crystal_system': ('system', _parse_system),
+    keywords = {
+        'id': ('authors', _parse_all),
+        'authors': ('authors', _parse_all),
+        'element': ('elements', _parse_all),
+        'number_of_elements': ('elementc', _parse_all),
+        'mineral_name': ('mineral', _parse_mineral),
+        'chemical_name': ('mineral', _parse_mineral),
+        'formula': ('formula', _parse_all),
+        'volume': ('volume', _parse_volume),
+        'a': ('volume', _parse_volume),
+        'b': ('volume', _parse_volume),
+        'c': ('volume', _parse_volume),
+        'alpha': ('volume', _parse_volume),
+        'beta': ('volume', _parse_volume),
+        'gamma': ('volume', _parse_volume),
+        'spacegroup': ('spaceg', _parse_all),
+        'journal': ('journal', _parse_all),
+        'title': ('title', _parse_all),
+        'year': ('year', _parse_all),
+        'crystal_system': ('system', _parse_system),
     }
 
     def query(self, **kwargs):
@@ -361,11 +360,10 @@ class IcsdDbImporter(DbImporter):
 
         :param kwargs: A list of ''keyword = [values]'' pairs.
         """
-
         if self.db_parameters['querydb']:
             return self._query_sql_db(**kwargs)
-        else:
-            return self._queryweb(**kwargs)
+
+        return self._queryweb(**kwargs)
 
     def _query_sql_db(self, **kwargs):
         """
@@ -377,13 +375,11 @@ class IcsdDbImporter(DbImporter):
 
         sql_where_query = []  # second part of sql query
 
-        for k, v in kwargs.items():
-            if not isinstance(v, list):
-                v = [v]
-            sql_where_query.append('({})'.format(self.keywords_db[k][1](self,
-                                                        self.keywords_db[k][0],
-                                                        k, v)))
-        if 'crystal_system' in kwargs.keys():  # to query another table than the main one, add LEFT JOIN in front of WHERE
+        for key, value in kwargs.items():
+            if not isinstance(value, list):
+                value = [value]
+            sql_where_query.append('({})'.format(self.keywords_db[key][1](self, self.keywords_db[key][0], key, value)))
+        if 'crystal_system' in kwargs:  # to query another table than the main one, add LEFT JOIN in front of WHERE
             sql_query = 'LEFT JOIN space_group ON space_group.sgr=icsd.sgr LEFT '\
                         'JOIN space_group_number ON '\
                         'space_group_number.sgr_num=space_group.sgr_num '\
@@ -395,7 +391,6 @@ class IcsdDbImporter(DbImporter):
 
         return IcsdSearchResults(query=sql_query, db_parameters=self.db_parameters)
 
-
     def _queryweb(self, **kwargs):
         """
         Perform a query on the Icsd web database using ``keyword = value`` pairs,
@@ -405,7 +400,7 @@ class IcsdDbImporter(DbImporter):
         :return: IcsdSearchResults
         """
         from urllib.parse import urlencode
-        self.actual_args = {
+        self.actual_args = {  # pylint: disable=attribute-defined-outside-init
             'action': 'Search',
             'nb_rows': '100',  # max is 100
             'order_by': 'yearDesc',
@@ -414,10 +409,10 @@ class IcsdDbImporter(DbImporter):
             'mineral': ''
         }
 
-        for k, v in kwargs.items():
+        for key, value in kwargs.items():
             try:
-                realname = self.keywords[k][0]
-                newv = self.keywords[k][1](k, v)
+                realname = self.keywords[key][0]
+                newv = self.keywords[key][1](key, value)
                 # Because different keys correspond to the same search field.
                 if realname in ['authors', 'volume', 'mineral']:
                     self.actual_args[realname] = self.actual_args[realname] + newv + ' '
@@ -439,8 +434,8 @@ class IcsdDbImporter(DbImporter):
         :param kwargs: db_parameters for the mysql database connection
           (host, user, passwd, db, port)
         """
-        for key in self.db_parameters.keys():
-            if key in kwargs.keys():
+        for key in self.db_parameters:
+            if key in kwargs:
                 self.db_parameters[key] = kwargs[key]
 
     def get_supported_keywords(self):
@@ -449,11 +444,11 @@ class IcsdDbImporter(DbImporter):
         """
         if self.db_parameters['querydb']:
             return self.keywords_db.keys()
-        else:
-            return self.keywords.keys()
+
+        return self.keywords.keys()
 
 
-class IcsdSearchResults(DbSearchResults):
+class IcsdSearchResults(DbSearchResults):  # pylint: disable=abstract-method,too-many-instance-attributes
     """
     Result manager for the query performed on ICSD.
 
@@ -465,8 +460,8 @@ class IcsdSearchResults(DbSearchResults):
     db_name = 'Icsd'
 
     def __init__(self, query, db_parameters):
-
-        self.db = None
+        # pylint: disable=super-init-not-called
+        self.db = None  # pylint: disable=invalid-name
         self.cursor = None
         self.db_parameters = db_parameters
         self.query = query
@@ -498,9 +493,9 @@ class IcsdSearchResults(DbSearchResults):
         if self.number_of_results > self.position:
             self.position = self.position + 1
             return self.at(self.position - 1)
-        else:
-            self.position = 0
-            raise StopIteration()
+
+        self.position = 0
+        raise StopIteration()
 
     def at(self, position):
         """
@@ -515,20 +510,23 @@ class IcsdSearchResults(DbSearchResults):
 
         if position not in self.entries:
             if self.db_parameters['querydb']:
-                self.entries[position] = IcsdEntry(self.db_parameters['server'] +
-                        self.db_parameters['dl_db'] + self.cif_url.format(
-                        self._results[position]),
-                    db_name=self.db_name, id=self.cif_numbers[position],
-                    version = self.db_version,
-                    extras={'idnum': self._results[position]})
+                self.entries[position] = IcsdEntry(
+                    self.db_parameters['server'] + self.db_parameters['dl_db'] +
+                    self.cif_url.format(self._results[position]),
+                    db_name=self.db_name,
+                    id=self.cif_numbers[position],
+                    version=self.db_version,
+                    extras={'idnum': self._results[position]}
+                )
             else:
-                self.entries[position] = IcsdEntry(self.db_parameters['server'] +
-                        self.db_parameters['dl_db'] + self.cif_url.format(
-                        self._results[position]),
-                    db_name=self.db_name, extras={'idnum': self._results[position]})
+                self.entries[position] = IcsdEntry(
+                    self.db_parameters['server'] + self.db_parameters['dl_db'] +
+                    self.cif_url.format(self._results[position]),
+                    db_name=self.db_name,
+                    extras={'idnum': self._results[position]}
+                )
         return self.entries[position]
 
-
     def query_db_version(self):
         """
         Query the version of the icsd database (last row of RELEASE_TAGS).
@@ -554,8 +552,7 @@ class IcsdSearchResults(DbSearchResults):
                 raise IcsdImporterExp('Database version not found')
 
         else:
-            raise NotImplementedError('Cannot query the database version with '
-                                      'a web query.')
+            raise NotImplementedError('Cannot query the database version with ' 'a web query.')
 
     def query_page(self):
         """
@@ -568,10 +565,9 @@ class IcsdSearchResults(DbSearchResults):
         if self.db_parameters['querydb']:
 
             self._connect_db()
-            query_statement = '{}{}{} LIMIT {}, 100'.format(self.sql_select_query,
-                                                            self.sql_from_query,
-                                                            self.query,
-                                                            (self.page-1)*100)
+            query_statement = '{}{}{} LIMIT {}, 100'.format(
+                self.sql_select_query, self.sql_from_query, self.query, (self.page - 1) * 100
+            )
             self.cursor.execute(query_statement)
             self.db.commit()
 
@@ -585,23 +581,21 @@ class IcsdSearchResults(DbSearchResults):
 
             self._disconnect_db()
 
-
         else:
-            from bs4 import BeautifulSoup
+            from bs4 import BeautifulSoup  # pylint: disable=import-error
             from urllib.request import urlopen
             import re
 
-            self.html = urlopen(self.db_parameters['server'] +
-                                self.db_parameters['db'] + '/' +
-                                self.query.format(str(self.page))).read()
+            self.html = urlopen(
+                self.db_parameters['server'] + self.db_parameters['db'] + '/' + self.query.format(str(self.page))
+            ).read()
 
             self.soup = BeautifulSoup(self.html)
 
             try:
 
                 if self.number_of_results is None:
-                    self.number_of_results = int(re.findall(r'\d+',
-                                                    str(self.soup.find_all('i')[-1]))[0])
+                    self.number_of_results = int(re.findall(r'\d+', str(self.soup.find_all('i')[-1]))[0])
             except IndexError:
                 raise NoResultsWebExp
 
@@ -617,11 +611,12 @@ class IcsdSearchResults(DbSearchResults):
         except ImportError:
             import pymysql as MySQLdb
 
-        self.db = MySQLdb.connect(host=self.db_parameters['host'],
-                                  user=self.db_parameters['user'],
-                                  passwd=self.db_parameters['passwd'],
-                                  db=self.db_parameters['db'],
-                                  port=int(self.db_parameters['port'])
+        self.db = MySQLdb.connect(
+            host=self.db_parameters['host'],
+            user=self.db_parameters['user'],
+            passwd=self.db_parameters['passwd'],
+            db=self.db_parameters['db'],
+            port=int(self.db_parameters['port'])
         )
         self.cursor = self.db.cursor()
 
@@ -632,7 +627,7 @@ class IcsdSearchResults(DbSearchResults):
         self.db.close()
 
 
-class IcsdEntry(CifEntry):
+class IcsdEntry(CifEntry):  # pylint: disable=abstract-method
     """
     Represent an entry from Icsd.
 
@@ -651,12 +646,14 @@ class IcsdEntry(CifEntry):
         """
         super().__init__(**kwargs)
         self.source = {
-            'db_name': kwargs.get('db_name','Icsd'),
+            'db_name': kwargs.get('db_name', 'Icsd'),
             'db_uri': None,
             'id': kwargs.get('id', None),
             'version': kwargs.get('version', None),
             'uri': uri,
-            'extras': {'idnum': kwargs.get('extras', {}).get('idnum', None)},
+            'extras': {
+                'idnum': kwargs.get('extras', {}).get('idnum', None)
+            },
             'license': self._license,
         }
 
@@ -668,10 +665,11 @@ class IcsdEntry(CifEntry):
         PyCifRW library (and most other sensible applications), expects UTF-8. Therefore, we decode
         the original CIF data to unicode and encode it in the UTF-8 format
         """
+        import urllib.request
+
         if self._contents is None:
             from hashlib import md5
-
-            self._contents = urlopen(self.source['uri']).read()
+            self._contents = urllib.request.urlopen(self.source['uri']).read()
             self._contents = self._contents.decode('iso-8859-1').encode('utf8')
             self.source['source_md5'] = md5(self._contents).hexdigest()
 
@@ -682,9 +680,8 @@ class IcsdEntry(CifEntry):
         :return: ASE structure corresponding to the cif file.
         """
         from aiida.orm import CifData
-
         cif = correct_cif(self.cif)
-        return CifData.read_cif(StringIO(cif))
+        return CifData.read_cif(io.StringIO(cif))
 
 
 def correct_cif(cif):
@@ -709,12 +706,12 @@ def correct_cif(cif):
         inc = 1
         while True:
             words = lines[author_index + inc].split()
-            #in case loop is finished -> return cif lines.
-            #use regular expressions ?
+            # in case loop is finished -> return cif lines.
+            # use regular expressions ?
             if len(words) == 0 or words[0] == 'loop_' or words[0][0] == '_':
                 return '\n'.join(lines)
-            elif ((words[0][0] == "'" and words[-1][-1] == "'")
-                  or (words[0][0] == '"' and words[-1][-1] == '"')):
+
+            if ((words[0][0] == "'" and words[-1][-1] == "'") or (words[0][0] == '"' and words[-1][-1] == '"')):
                 # if quotes are already there, check next line
                 inc = inc + 1
             else:
