@@ -47,21 +47,50 @@ class Transport(abc.ABC):
     _valid_auth_params = None
     _MAGIC_CHECK = re.compile('[*?[]')
     _valid_auth_options = []
-    _common_auth_options = [(
-        'safe_interval', {
-            'type': float,
-            'prompt': 'Connection cooldown time (s)',
-            'help': 'Minimum time interval in seconds between consecutive connection openings',
-            'callback': validate_positive_number
-        }
-    )]
+    _common_auth_options = [
+        (
+            'use_login_shell', {
+                'default':
+                True,
+                'switch':
+                True,
+                'prompt':
+                'Use login shell when executing command',
+                'help':
+                ' Not using a login shell can help suppress potential'
+                ' spurious text output that can prevent AiiDA from parsing the output of commands,'
+                ' but may result in some startup files (.profile) not being sourced.',
+                'non_interactive_default':
+                True
+            }
+        ),
+        (
+            'safe_interval', {
+                'type': float,
+                'prompt': 'Connection cooldown time (s)',
+                'help': 'Minimum time interval in seconds between opening new connections.',
+                'callback': validate_positive_number
+            }
+        ),
+    ]
 
     def __init__(self, *args, **kwargs):  # pylint: disable=unused-argument
         """
         __init__ method of the Transport base class.
+
+        :param safe_interval: (optional, default self._DEFAULT_SAFE_OPEN_INTERVAL)
+           Minimum time interval in seconds between opening new connections.
+        :param use_login_shell: (optional, default True)
+           if False, do not use a login shell when executing command
         """
         from aiida.common import AIIDA_LOGGER
         self._safe_open_interval = kwargs.pop('safe_interval', self._DEFAULT_SAFE_OPEN_INTERVAL)
+        self._use_login_shell = kwargs.pop('use_login_shell', True)
+        if self._use_login_shell:
+            self._bash_command_str = 'bash -l '
+        else:
+            self._bash_command_str = 'bash '
+
         self._logger = AIIDA_LOGGER.getChild('transport').getChild(self.__class__.__name__)
         self._logger_extra = None
         self._is_open = False
@@ -159,11 +188,17 @@ class Transport(abc.ABC):
 
     @classmethod
     def get_valid_transports(cls):
-        """
-        :return: a list of existing plugin names
-        """
-        from aiida.plugins.entry_point import get_entry_point_names
+        """Return the list of registered transport entry points.
 
+        .. deprecated:: 1.4.0
+
+            Will be removed in `2.0.0`, use `aiida.plugins.entry_point.get_entry_point_names` instead
+        """
+        import warnings
+        from aiida.common.warnings import AiidaDeprecationWarning
+        from aiida.plugins.entry_point import get_entry_point_names
+        message = 'method is deprecated, use `aiida.plugins.entry_point.get_entry_point_names` instead'
+        warnings.warn(message, AiidaDeprecationWarning)  # pylint: disable=no-member
         return get_entry_point_names('aiida.transports')
 
     @classmethod
@@ -193,6 +228,13 @@ class Transport(abc.ABC):
         """
         return cls._DEFAULT_SAFE_OPEN_INTERVAL
 
+    @classmethod
+    def _get_use_login_shell_suggestion_string(cls, computer):  # pylint: disable=unused-argument
+        """
+        Return a suggestion for the specific field.
+        """
+        return 'True'
+
     @property
     def logger(self):
         """
@@ -756,6 +798,18 @@ class Transport(abc.ABC):
     def has_magic(self, string):
         return self._MAGIC_CHECK.search(string) is not None
 
+    def _gotocomputer_string(self, remotedir):
+        """command executed when goto computer."""
+        connect_string = (
+            """ "if [ -d {escaped_remotedir} ] ;"""
+            """ then cd {escaped_remotedir} ; {bash_command} ; else echo '  ** The directory' ; """
+            """echo '  ** {remotedir}' ; echo '  ** seems to have been deleted, I logout...' ; fi" """.format(
+                bash_command=self._bash_command_str, escaped_remotedir="'{}'".format(remotedir), remotedir=remotedir
+            )
+        )
+
+        return connect_string
+
 
 class TransportInternalError(InternalError):
     """
